bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Handschrift A ## 5. Aventiure
___________________________________________________ #### Wie Sifrit Krimhilt erst <gesach>
| ### an sach si tegilichen nu riten an den Rin ### die zer hohgecite gerne wolden sin ### die durch des kvniges liebe chomen in daz lant ### den bot man svmelichen ros vnd gewant
###### 265 | ### In was ir gesidele allen wol bereit ### den hohsten vnd den besten als vns daz ist geseit ### zwein vnd drizech fursten da zer hohgezit ### da cierten sich engegene alle vrowen wider strit
###### 266 | ### Ez was da vil vnmuezech Gyselher daz kint ### die geste mit den kvnden vil guetlichen sint ### die enphieng er vnd Gernot vnd ovch ir beider man ### ia gruozten si dich degne als ez nach eren was getan
###### 267 | ### Vil golt roter setle si fuorten in daz lant ### cierliche schilde vnd erlich gewant ### brahten si ze Rine zvo der hohgezit ### manigen vngesvnden sach man frolichen sit
###### 268 | ### Die in den beten lagen vnd heten wnden not ### die muosen des vergezen wie herte was der tot ### die siechen vngesvnden mvosen si verchlagen ### si vrovten sich der mere gen den hohgezite tagen
###### 269 | ### wie si leben solden da ze der wirtschaft ### wunne ane maze mit frovden vber chraft ### heten al die lûte swaz man ir da vant ### des hvop sich michel frovde vber al daz Gvnthers lant
###### 270 | ### An einem pfinchsten morgen sach man fur gan ### gechleidet wunnechliche vil manigen kuenen man ### fvnf tvsent oder mere da cer hohgecit ### sich huop div chvrzewile an manigen enden wider strit
###### 271 | ### Der wirt der het die sinne im was daz wol erkant ### wie rehte herzenliche der helt von Niderlant ### sine swester trûte die er noch nie gesach ### der man so grozer schoene vor allen iwnchvrovwen jach
###### 272 | ### So sprach zuo dem kvnige der degen Ortwin ### welt ir mit vollen eren ze der hochzite sin ### so svlt ir lazen schovwen div wunnechlichen kint ### die mit so grozen eren zen Burgonden sint
###### 273 | ### Waz wære mannes wunne des frovte sic sin wip ### ez entæten schoene meide vnd herlichiv wip ### lazet iwer swester fur iwer geste gan ### der rat was ze liebe vil manigem helde getan
###### 274 | ### Des wil ich gerne volgen sprach der kvnich do ### alle die ez erfvnden warns harte fro ### ern bot ez frovn voden vnd ir tohter wolgetan ### daz si mit ir meiden hin ze houe solde gan
###### 275 | ### Do wart vz den schrinen geschvchet guot gewant [12a] ### swaz man in der valde der guoten wæte vant ### die bovge mit den borten daz was in vil bereit ### sich zierte riterliche manich wætlichiu meit
###### 276 | ### Vil manich reche tvmber des tages hete mvot ### daz er an ze sehene den frovwen were gvot ### daz er da fvr niht næme eins riken kvniges lant ### si sahen die vil gerne die si heten bekant
###### 277 | ### Do hiez der kvnich riche mit siner swester gan ### die ir dienen solden hvndert siner man ### ir vnd siner mage die truogen swert enhant ### daz was daz hofgesinde in der Bvrgonden lant
###### 278 | ### voten die vil richen sach man mit ir chomen ### div hete schoeniv frovwen gesellichlich genomen ### hvndert oder mere die trvogen richiv cleit ### ovch gie da nach ir tohter manich wetlichiu meit
###### 279 | ### Von einer kemenaten sach man si alle gan ### do wart vil michel dringen von helden dar getan ### die des gedinge heten ob chvnde daz geschehen ### daz si die mait edele solden vrolichen sehen
###### 280 | ### Nv gie div minnecliche also der morgenrot ### tuot vz truoben wolchen da schiet von maniger not ### der si da truoch in herzen vnd lange hete getan ### er sach die minneclichen nv uil herlichen stan
###### 281 | ### Ja luhte ir von ir wæte vil manich edel stein ### ir rosen rotiv varwe vil minnechlichen schin ### ob iemen wunsen solde der kvnde niht geiehen ### daz er ce dirre werlde hete iht schoeners gesehen
###### 282 | ### Sam der liehte mane vor deme sterne stat ### der schin so lûterliche ob den wolchen gat ### dem stvont si nu geliche vor andern frovwen guot ### des wart wol gehoehet vil maniges heldes mvot
###### 283 | ### Die riken kamerere sach man vor in gan ### die hoh gemvoten degne wolden des niht lan ### sin drvngen da si sahen die minnechlichen meit ### Sifride dem herren wart beide liep vnd leit
###### 284 | ### Er dahte in sinem mvote wie kvnde daz ergan ### daz ich dich minnen solde daz ist ein tvmber wan ### sol aber ich dich fremden so wære ich samfter tot ### er von gedanken dike bleich vnde rot
###### 285 | ### Do stvont so minnechliche daz Siglinde kint ### sam er entworfen were an ein permeint ### von guotes meisters listen so man in iach ### daz man helt neheinen so schoenen nie gesach
###### 286 | ### Die mit der frovwen giengen die hiezen von den wegen ### wichen allenthalben daz leiste manich degen ### div hoch traginden herzen vrovten manigen lip ### man sach in hohen zvhten manich wetliche wip
###### 287 | ### Do sprach von Bvrgonden der herre Gernot ### der iv sinen dinest so guotlichen bot ### Gvnther lieber bruoder dem sult ir tuon alsam [12b] ### vor allen disen reken des rates ich mich nimmer gescham
###### 288 | ### Ir heizet Sifriden zvo miner swester kvomen ### daz in div maget gruoze des habe wir immer fruomen ### div nie gruozte reken div sol in gruozen pflegen ### da mit wir han gewunnen den cierlichen degen
###### 289 | ### Do giengen des wirtes magen da man den helt vant ### si sprachen zuo dem reken vzer Niderlant ### iv hat der kvnich erlovbet ir svlt ze hove gan ### sin swester sol ivch gruozen daz ist ze eren iv getan
###### 290 | ### Der herre in sinen mvote was des vil gemeit ### do truoch er in dem herzen liep ane leit ### daz er sehen solde der schoenen voten kint ### mit minneclichen tvgenden si gruozte Sifriden sint
###### 291 | ### Do si den hoch gemvoten vor ir stende sach ### do erzvnde sich sin varwe div schoene meit sprach ### sit willechomen er Sifrit ein edel riter guot ### do wart im von dem gruoze wol gehohet sin muot
###### 292 | ### Er neig ir minnechlichen genade er ir bot ### si twanch gen ein ander der seneden minne not ### mit lieben ovgen blichen an ander sahen an ### der herre vnd ovch div frovwe daz wart vil tavgen getan
###### 293 | ### Wart da wrüntliche getrutet ir vil wiziv hant ### von herzenlieber minne des ist mir niht bechant ### doch wil ich niht gelovben daz ez wrde lam ### zwei minne gerndiv herze heten anders missetan
###### 294 | ### Bi der svmerzite vnd gen des meyen tagen ### dorft er nihe mere in sime herze tragen ### so vil hoher vrovde so er da gewan ### do im div gie an hende die er ze trûte gerte han
###### 295 | ### Do dahte manich reke hey wer mir sam geschehen ### daz ich ir gienge nebene als ich in han gesehen ### oder bi ce ligenne daz liez ich ane <haz > ### er gediente noch nie reke nach einer kvniginne baz
###### 296 | ### Von swelher kvnige lande die geste komen dar ### die namen algeliche wan ir zweier war ### ir wart erlovbet kvssen den wertlichen man ### im wart ze dirre werlde nie so liebe getan
###### 297 | ### Der kvnich von Tenemarke sprach do sa cestunt ### des vil hohen gruozes lit vil maniger wunt ### des ich da wol enpfinde von Sifrides hant ### got laze in nimmer me ze Tenemarch in daz lant
###### 298 | ### Man hiez do allenthalben wichen von den wegen ### der schoenen Kriemhilde manigen kuenen degen ### sach man zvchtechliche ze kirche mit ir gan ### sit wart von ir gescheiden der vil wætliche man
###### 299 | ### Do gie si zvo dem mvnster ir volgete manich wip ### do was ovch wol gezieret der kvneginne lip ### daz da hoher wnse maniger wart verlorn ### si was ze ovgenweide manigem reke geborn [13a]
###### 300 | ### Vil kvme beite Sifrit daz man da gesanch ### er mohte sinen selden immer sagen danch ### daz im div was so wege die er in herzen truoch ### ovch was er der schoenen holt von schvlden genuoch
###### 301 | ### Do si vz dem mvnstre nach messe chom gestan ### man bat den degen kuenen wider zvo ir gan ### erst begund im danchen div minneclike meit ### daz er vor den reken so wichlichen streit
###### 302 | ### Nv lon iv got er Sifrit sprach daz edel kint ### daz ir daz habet verdienet daz iv die reken sint ### so holt in guoten triwen so ich si hore iehen ### do begunde er minnechliche an frovn Kriemhilde sehen
###### 303 | ### Ich sol ivch immer dienen sprach Sifrit der degen ### vnd enwil min hovbet nimmer ê gelegen ### ich en werbe nach ir willen sol ich min leben han ### daz mvoz iv ze dienste min frov Kriemhilt sin getan
###### 304 | ### Inre tagen zweluen der tage als islich ### sach man bi dem degne die maget lobilich ### so si ze houe solde vor ir frivnden gan ### der dienst wart dem reken durch groze liebe getan
###### 305 | ### Frovde vnde wnne vnd michelen schal ### sach man tegeliche vor Gvnthers sal ### darvze vnd ovch darinne vil manigen kvenen man ### Ortwin vnd Hagne grozer wunder vil began
###### 306 | ### Swes ieman pflegen solde des warn si bereit ### mit volleclicher maze die helde vil gemeit ### des wurden von den gesten die rechen wol bechant ### davon so was gezieret allez Gvnthers lant
###### 307 | ### Die da wunde lagen die sah man da fur gan ### si wolden kvrcewile mit dem gesinde han ### schirmen mit den schilden vnd schiezen manigen schaft ### des hulfen in genvoge si heten michel chraft
###### 308 | ### In der hochzite der wirt hiez ir phlegen ### mit der beste spise er hete sich begwegen ### aller schlahte schande die ie kvnich gewan ### man sach in friuntliche zvo sinen gesten gan
###### 309 | ### Er sprach ir gvoten reken e ir scheidet hin ### so nemet mine gabe also stet min sin ### daz ichz immer diene versmehet niht min gvot ### daz wil ich mit iv teilen des han ich vesten mvot
###### 310 | ### Die von Tenemarken sprachen sa zehant ### ê wir wider riten heim in vnser lant ### wir gern steter schuone des ist vns reken not ### wir han von iwren degnen manigen lieben frivnt tot
###### 311 | ### Livdgast geheilet siner wunden was ### der voit von den Sahsen nach strite wol genas ### eteliche toten si liezen da ze lant ### do gie der kvnich Gunther da er Sifriden vant
###### 312 | ### Er sprach zuo deme reken nv rate wie ich tuo ### vnser geste wellent morgen riten fruo [13b] ### vnd gerent steter svone an mich vnd an mine man ### nv rata degen Sifrit waz des guot si getan
###### 313 | ### Waz mir die herren bieten daz wil ich dir sagen ### swaz funf hundert moere goldes mvgen tragen ### daz gebent si mir gerne wil ich si ledich lan ### do sprach Sifrit daz wer vbel getan
###### 314 | ### Ir svlt si ledechlichen hinnen lazen varn ### vnd daz die reken edele furbaz bewarn ### vienthlichez riten her in iwr lant ### des lat iv geben sicherheit beider herren hant
###### 315 | ### Des rates wil ich volgen da mit si riten dan ### sinen vienden wart daz kvnt getan ### ir goldes gerte niemen daz si da buten ê ### da heim ir lieben frivnden was nach den hermueden we
###### 316 | ### Manigen schilt vollen man <dar> schazzes truoch ### er teilte es ane wage sinen frivnden genuoch ### bi funfhvndert marken vnd eteslichen baz ### Gernot der vil kuene riet <Gvnther> daz
###### 317 | ### Vrlop si do namen also si wolden dan ### do sach man die geste fur Kriemhilde gan ### vnd ovch da frov Vote div kvniginne saz ### ez wrden nie degne mere gevrlovbet baz
###### 318 | ### Herberge wurden lere do si dannen riten ### doch bestuont deheime mit herlichen siten ### der kvnich mit den sinen vnd manich edel man ### die sach man tegliche zvo Chriemhilde gan
###### 319 | ### Vrlovp nemen wolde ovch Sifrit ein helt guot ### er wande niht erwerben des er hete muot ### der kvnich sagen horte daz er wolde dan ### Giselher der iunge von der reise in gewan
###### 320 | ### War woldet ir nv riten edel Sifrit ### belibet bi den reken tuot des ich iv bit ### <bi> Gvnther dem kvnige vnd bi sinen man ### hie sint vil schoene frovwen die man ivch sol sehen lan
###### 321 | ### Do sprach der starke Sifrit so lat div ros stan ### ich wolde sin geriten des wil ich abe gan ### vnd traget hin die schilde ich wolde sin ce lant ### des hat mich Giselher mit eren wol erwant
###### 322 | ### Sus beleip der kuene durch frivnde lobe da ### ia wær er in den landen ninder anderswa ### gewesen alse sanfte da von daz gesach ### <[daz er nu tegeliche die schoenen Kriemhilde sach]>
###### 323 | ### Ddurch ir vnmazen schoene der herre da beleip ### mit maniger chvrzwile man nu die zit vertreip ### wan daz in twanch ir minne div gap im diche not ### darvmbe sit der kvene lac uil iemerlichen tot

<<< Übersicht <<< vorige Seite nächste Seite >>>